==> fb_vmware-0.5.5-py3-none-any.whl: fb_vmware/xlate.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@author: Frank Brehm
@contact: frank@brehm-online.com
@copyright: © 2022 by Frank Brehm, Berlin
@summary: The module for i18n.
          It provides translation object, usable from all other
          modules in this package.
"""
from __future__ import absolute_import, print_function

# Standard modules
import logging
import gettext
import copy

try:
    from pathlib import Path
except ImportError:
    from pathlib2 import Path

# Third party modules
import babel
import babel.lists
from babel.support import Translations

try:
    from packaging.version import Version
except ImportError:
    from distutils.version import LooseVersion as Version

DOMAIN = 'fb_vmware'

LOG = logging.getLogger(__name__)

__version__ = '0.1.2'

__me__ = Path(__file__).resolve()
__module_dir__ = __me__.parent
__lib_dir__ = __module_dir__.parent
__base_dir__ = __lib_dir__.parent
LOCALE_DIR = __base_dir__.joinpath('locale')
if not LOCALE_DIR.is_dir():
    LOCALE_DIR = __module_dir__.joinpath('locale')
    if not LOCALE_DIR.is_dir():
        LOCALE_DIR = None

DEFAULT_LOCALE_DEF = 'en_US'
DEFAULT_LOCALE = babel.core.default_locale()
if not DEFAULT_LOCALE:
    DEFAULT_LOCALE = DEFAULT_LOCALE_DEF

__mo_file__ = gettext.find(DOMAIN, str(LOCALE_DIR))
if __mo_file__:
    try:
        with open(__mo_file__, 'rb') as F:
            XLATOR = Translations(F, DOMAIN)
    except IOError:
        XLATOR = gettext.NullTranslations()
else:
    XLATOR = gettext.NullTranslations()

CUR_BABEL_VERSION = Version(babel.__version__)
NEWER_BABEL_VERSION = Version('2.6.0')

SUPPORTED_LANGS = (
    'de_DE',
    'en_US'
)

_ = XLATOR.gettext


# =============================================================================
def format_list(lst, do_repr=False, style='standard', locale=DEFAULT_LOCALE):
    """
    Format the items in `lst` as a list.
    :param lst: a sequence of items to format in to a list
    :param locale: the locale
    """
    if not lst:
        return ''

    my_list = copy.copy(lst)
    if do_repr:
        my_list = []
        for item in lst:
            my_list.append('{!r}'.format(item))

    if CUR_BABEL_VERSION < NEWER_BABEL_VERSION:
        return babel.lists.format_list(my_list, locale=locale)
    return babel.lists.format_list(my_list, style=style, locale=locale)


# =============================================================================

if __name__ == "__main__":

    out_list = []
    out_list.append([_("Module directory:"), str(__module_dir__)])
    out_list.append([_("Base directory:"), str(__base_dir__)])
    out_list.append([_("Locale directory:"), str(LOCALE_DIR)])
    out_list.append([_("Locale domain:"), DOMAIN])
    out_list.append([_("Found .mo-file:"), __mo_file__])

    max_len = 1
    for pair in out_list:
        if len(pair[0]) > max_len:
            max_len = len(pair[0])

    template = "{{label:<{}}} {{val!r}}".format(max_len)
    for pair in out_list:
        print(template.format(label=pair[0], val=pair[1]))


# =============================================================================

# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4

==> fb_vmware-1.0.0-py3-none-any.whl: fb_vmware/xlate.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@summary: The module for i18n.

          It provides a translation object, usable from all other
          modules in this package.

@author: Frank Brehm
@contact: frank@brehm-online.com
@copyright: © 2024 by Frank Brehm, Berlin
"""
from __future__ import absolute_import, print_function

# Standard modules
import copy
import gettext
import logging
try:
    from pathlib import Path
except ImportError:
    from pathlib2 import Path

# Third party modules
import babel
import babel.lists
from babel.support import Translations

try:
    from packaging.version import Version
except ImportError:
    from distutils.version import LooseVersion as Version

DOMAIN = 'fb_vmware'

LOG = logging.getLogger(__name__)

__version__ = '1.0.1'

__me__ = Path(__file__).resolve()
__module_dir__ = __me__.parent
__lib_dir__ = __module_dir__.parent
__base_dir__ = __lib_dir__.parent
LOCALE_DIR = __base_dir__.joinpath('locale')
if not LOCALE_DIR.is_dir():
    LOCALE_DIR = __module_dir__.joinpath('locale')
    if not LOCALE_DIR.is_dir():
        LOCALE_DIR = None

USED_LOCALE_DIR = None
if LOCALE_DIR:
    USED_LOCALE_DIR = str(LOCALE_DIR)

DEFAULT_LOCALE_DEF = 'en_US'
DEFAULT_LOCALE = babel.core.default_locale()
if not DEFAULT_LOCALE:
    DEFAULT_LOCALE = DEFAULT_LOCALE_DEF

__mo_file__ = gettext.find(DOMAIN, USED_LOCALE_DIR)
if __mo_file__:
    try:
        with open(__mo_file__, 'rb') as F:
            XLATOR = Translations(F, DOMAIN)
    except IOError:
        XLATOR = gettext.NullTranslations()
else:
    XLATOR = gettext.NullTranslations()

CUR_BABEL_VERSION = Version(babel.__version__)
NEWER_BABEL_VERSION = Version('2.6.0')

SUPPORTED_LANGS = (
    'de_DE',
    'en_US'
)

_ = XLATOR.gettext


# =============================================================================
def format_list(lst, do_repr=False, style='standard', locale=DEFAULT_LOCALE):
    """
    Format the items in `lst` as a list.

    :param lst: a sequence of items to format in to a list
    :param locale: the locale
    """
    if not lst:
        return ''

    my_list = copy.copy(lst)
    if do_repr:
        my_list = []
        for item in lst:
            my_list.append('{!r}'.format(item))

    if CUR_BABEL_VERSION < NEWER_BABEL_VERSION:
        return babel.lists.format_list(my_list, locale=locale)
    return babel.lists.format_list(my_list, style=style, locale=locale)


# =============================================================================

if __name__ == '__main__':

    out_list = []
    out_list.append([_('Module directory:'), str(__module_dir__)])
    out_list.append([_('Base directory:'), str(__base_dir__)])
    out_list.append([_('Locale directory:'), USED_LOCALE_DIR])
    out_list.append([_('Locale domain:'), DOMAIN])
    out_list.append([_('Found .mo-file:'), __mo_file__])

    max_len = 1
    for pair in out_list:
        if len(pair[0]) > max_len:
            max_len = len(pair[0])

    template = '{{label:<{}}} {{val!r}}'.format(max_len)
    for pair in out_list:
        print(template.format(label=pair[0], val=pair[1]))


# =============================================================================

# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
